@@ -20,6 +20,7 @@ import botocore
 import shutil
 from cogniceptshell.common import bcolors
 from cogniceptshell.common import generate_progress_bar
+from cogniceptshell.common import permission_safe_docker_call
 from subprocess import DEVNULL
 from docker.types import LogConfig
 
@@ -129,7 +130,10 @@ class AgentLifeCycle:
                         args: populated argument namespace returned by `argparse.parse_args()`
 
         """
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         # check status of cgs_agent
         # get latest log location
         latest_log_loc = object._get_latest_log_loc(args)
@@ -330,8 +334,11 @@ class AgentLifeCycle:
         # if list of agents is not specified, restart all
         if(not hasattr(args, 'list') or len(args.list) == 0):
             args.list = object._docker_container_names
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
 
-        client = docker.from_env()
+        client = permission_docker_call_result
         print("STOP: ")
         flag_success = True
         for container_name in args.list:
@@ -386,7 +393,10 @@ class AgentLifeCycle:
             args.config.config_path + "bags/": {"bind": "/root/.cognicept/bags", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["other"] = {
             "command": "", "network_mode": "host"}
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         print("RUN: ")
         success_flag = True
         for container_name in args.list:
@@ -414,7 +424,10 @@ class AgentLifeCycle:
                 options["tty"] = True
                 options["log_config"] = LogConfig(
                     type=LogConfig.types.JSON, config={'max-size': '5m'})
-                command = options.pop("command")
+                if "command" in options:
+                    command = options.pop("command")
+                else:
+                    command = ""
                 container = client.containers.run(
                     object._docker_images[container_name], command, **options)
                 print(bcolors.OKBLUE + "DONE" + bcolors.ENDC)
@@ -461,7 +474,10 @@ class AgentLifeCycle:
                         None
         """
         os.system("xhost +local:root")
-        client = docker.from_env()
+        permission_docker_call_result = permission_safe_docker_call(docker.from_env)
+        if permission_docker_call_result is None:
+            return False
+        client = permission_docker_call_result
         try:
             options = {}
             options["name"] = "orbitty"
@@ -644,8 +660,13 @@ class AgentLifeCycle:
                 # Get registry
                 registry = token['authorizationData'][0]['proxyEndpoint']
                 # Login
-                object.docker_client = docker.APIClient(
-                    base_url='unix://var/run/docker.sock')
+                docker_call_result = permission_safe_docker_call(docker.APIClient,
+                                                                 base_url='unix://var/run/docker.sock')
+                if docker_call_result is None:
+                    return False
+
+                object.docker_client = docker_call_result
+
                 object.docker_client.login(username, password,
                                            registry=registry, reauth=True)
                 # Return true for successful login
